==> pathway-0.4.1-cp310-abi3-macosx_10_15_x86_64.macosx_11_0_arm64.macosx_10_15_universal2.whl: pathway/tests/test_flatten.py <==
# Copyright © 2023 Pathway

from __future__ import annotations

from typing import Any, List

import pandas as pd

import pathway as pw
from pathway import Table, this
from pathway.tests.utils import T, assert_table_equality_wo_index


def test_flatten_simple():
    tab = T(
        pd.DataFrame.from_dict({"col": [[1, 2, 3, 4]]}), format="pandas"
    ).with_columns(col=pw.declare_type(List[int], pw.this.col))

    assert_table_equality_wo_index(
        tab.flatten(this.col, origin_id=this.id),
        T(
            """
    col | origin_id
      1 | 0
      2 | 0
      3 | 0
      4 | 0
    """,
        ).with_columns(origin_id=tab.pointer_from(this.origin_id)),
    )


def test_flatten_no_origin():
    tab = T(
        pd.DataFrame.from_dict({"col": [[1, 2, 3, 4]]}), format="pandas"
    ).with_columns(col=pw.declare_type(List[int], pw.this.col))

    assert_table_equality_wo_index(
        tab.flatten(this.col),
        T(
            """
    col
      1
      2
      3
      4
    """,
        ),
    )


def test_flatten_inner_repeats():
    tab = T(
        pd.DataFrame.from_dict({"col": [[1, 1, 1, 3]]}), format="pandas"
    ).with_columns(col=pw.declare_type(List[int], pw.this.col))

    assert_table_equality_wo_index(
        tab.flatten(this.col, origin_id=this.id),
        T(
            """
    col | origin_id
      1 | 0
      1 | 0
      1 | 0
      3 | 0
    """,
        ).with_columns(origin_id=tab.pointer_from(this.origin_id)),
    )


def test_flatten_more_repeats():
    tab = T(
        pd.DataFrame.from_dict({"col": [[1, 1, 1, 3], [1]]}), format="pandas"
    ).with_columns(col=pw.declare_type(List[int], pw.this.col))

    assert_table_equality_wo_index(
        tab.flatten(this.col, origin_id=this.id),
        T(
            """
    col | origin_id
      1 | 0
      1 | 0
      1 | 0
      3 | 0
      1 | 1
    """,
        ).with_columns(origin_id=tab.pointer_from(this.origin_id)),
    )


def test_flatten_empty_lists():
    tab = T(pd.DataFrame.from_dict({"col": [[], []]}), format="pandas")

    assert_table_equality_wo_index(
        tab.flatten(this.col, origin_id=this.id),
        Table.empty(col=Any, origin_id=pw.Pointer),
    )

==> pathway-0.5.0-cp310-abi3-macosx_10_15_x86_64.macosx_11_0_arm64.macosx_10_15_universal2.whl: pathway/tests/test_flatten.py <==
# Copyright © 2023 Pathway

from __future__ import annotations

from typing import Any

import pandas as pd

import pathway as pw
from pathway import Table, this
from pathway.tests.utils import T, assert_table_equality_wo_index


def test_flatten_simple():
    tab = T(
        pd.DataFrame.from_dict({"col": [[1, 2, 3, 4]]}), format="pandas"
    ).with_columns(col=pw.declare_type(list[int], pw.this.col))

    assert_table_equality_wo_index(
        tab.flatten(this.col, origin_id=this.id),
        T(
            """
    col | origin_id
      1 | 0
      2 | 0
      3 | 0
      4 | 0
    """,
        ).with_columns(origin_id=tab.pointer_from(this.origin_id)),
    )


def test_flatten_no_origin():
    tab = T(
        pd.DataFrame.from_dict({"col": [[1, 2, 3, 4]]}), format="pandas"
    ).with_columns(col=pw.declare_type(list[int], pw.this.col))

    assert_table_equality_wo_index(
        tab.flatten(this.col),
        T(
            """
    col
      1
      2
      3
      4
    """,
        ),
    )


def test_flatten_inner_repeats():
    tab = T(
        pd.DataFrame.from_dict({"col": [[1, 1, 1, 3]]}), format="pandas"
    ).with_columns(col=pw.declare_type(list[int], pw.this.col))

    assert_table_equality_wo_index(
        tab.flatten(this.col, origin_id=this.id),
        T(
            """
    col | origin_id
      1 | 0
      1 | 0
      1 | 0
      3 | 0
    """,
        ).with_columns(origin_id=tab.pointer_from(this.origin_id)),
    )


def test_flatten_more_repeats():
    tab = T(
        pd.DataFrame.from_dict({"col": [[1, 1, 1, 3], [1]]}), format="pandas"
    ).with_columns(col=pw.declare_type(list[int], pw.this.col))

    assert_table_equality_wo_index(
        tab.flatten(this.col, origin_id=this.id),
        T(
            """
    col | origin_id
      1 | 0
      1 | 0
      1 | 0
      3 | 0
      1 | 1
    """,
        ).with_columns(origin_id=tab.pointer_from(this.origin_id)),
    )


def test_flatten_empty_lists():
    tab = T(pd.DataFrame.from_dict({"col": [[], []]}), format="pandas")

    assert_table_equality_wo_index(
        tab.flatten(this.col, origin_id=this.id),
        Table.empty(col=Any, origin_id=pw.Pointer),
    )
